<?php
// Quick-LP
// Copyright (c) Radius17
// Web: https://quick-lp.ru
// Commercial license https://quick-lp.ru/license.txt
// THE SOFTWARE IS PROVIDED 'AS IS', WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
// Revision: e165319 (2018-08-28 12:22:43)
//

defined('_QUICK_LP') or die("Access denied");

class QLPPlugin extends QLPSimpleObject {
	private static $_loaded  = array();
	private static $_enabled = array();
	protected $_events=array();
	
	private function __construct($pluginName) {
		$this->initSimpleObject($pluginName);
	}
	protected function registerEvents(){
		foreach($this->_events as $_event){
			QLPEvent::register($_event,$this->getName());
		}
	}
	public function prepare(){ 
		$this->registerEvents();
	}
	public static function initialize() {
		$enabled = parse_ini_file(QLP_PLUGINS."plugins.ini",false);
		foreach ($enabled as $key=>$value) {
			self::$_enabled[$key] = intval($value);
		}
		$_plugins = QLPFilesystem::getFolders(QLP_PLUGINS);
		if(count($_plugins)){
			foreach($_plugins as $_plugin=>$_data){
				if(is_file(QLP_PLUGINS.$_plugin.DS."index.php")){
					if (self::isEnabled($_plugin)){
						require_once QLP_PLUGINS.$_plugin.DS."index.php";
						$pluginClass=$_plugin."QLPPlugin";
						if (class_exists($pluginClass,0)) {
							self::$_loaded[$_plugin] = new $pluginClass($_plugin);
							self::$_loaded[$_plugin]->prepare();
						}
					}
				}
			}	
		}
	}
	public static function isEnabled($_plugin){
		if(array_key_exists($_plugin, self::$_enabled)) return self::$_enabled[$_plugin]; 
		else return 0;
	}
	public function executeEvent($event,$params, &$data){ 
		foreach ($params as $key=>$value) {
			$this->set($key,$value);
		}
		return $this->onRaise($event, $data);
	}
	protected function onRaise($event, &$data) { } 	
	public static function getInstance($name) {
		if (array_key_exists($name,self::$_loaded)) {
			return self::$_loaded[$name];
		}	else {
			QLPUtil::halt("Plugin not installed => ".$name);
		}
	}
}

class QLPEvent {
	private static $_events	= array();
	public static function register($eventName,$pluginName) {
		if (array_key_exists($eventName,self::$_events) && array_key_exists($pluginName,self::$_events[$eventName])) {
			QLPDebugger::getInstance()->warning("Event reregistration");
		} else {
			self::$_events[$eventName][$pluginName] = $pluginName;
			QLPDebugger::getInstance()->message("Event registered: ".$pluginName."=&gt;".$eventName);
		}
	}
	public static function isRegistered($eventName){
		if (array_key_exists($eventName,self::$_events)) {
			return true;
		} 
		return false;
	}
	public static function raise($eventName, $params=array(), &$data=null) {
		$result=null;
		if (array_key_exists($eventName,self::$_events)) {
			QLPDebugger::getInstance()->message("Event raised : ".$eventName);
			foreach (self::$_events[$eventName] as $plugin=>$val) {
				$result=QLPPlugin::getInstance($plugin)->executeEvent($eventName,$params, $data);
			}
		}
		return $result;
	}
	public static function test(){
		var_dump(self::$_events);
	}
}

?>