<?php
// Quick-LP
// Copyright (c) Radius17
// Web: https://quick-lp.ru
// Commercial license https://quick-lp.ru/license.txt
// THE SOFTWARE IS PROVIDED 'AS IS', WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
// Revision: 1602b67 (2019-04-02 18:06:00)
//

defined('_QUICK_LP') or die("Access denied");

class QLPRequest {
	private static function getFrom($arr, $name, $def=null) {
		$return = null;
		if (is_array($arr)) {
			if (isset($arr[$name])) $return = $arr[$name];
		}	else if(is_object($arr)) {
			if (property_exists($arr,$name)) $return = $arr->$name;
		}	else return $def;
		if($return == null) return $def;
		if (is_string($return)) $return = trim($return);
		return $return;
	}
	public static function get($key, $defVal='', $type='REQUEST') {
		switch(strtolower($type)) {
			case 'get':
				return self::getFrom($_GET, $key, $defVal);
				break;
			case 'post':
				return self::getFrom($_POST, $key, $defVal);
				break;
			case 'cookie':
				return self::getFrom($_COOKIE, $key, $defVal);
				break;
			case 'server':
				return self::getFrom($_SERVER, $key, $defVal);
				break;
			default:
				return self::getFrom($_REQUEST, $key, $defVal);
				break;
		}
	}
	public static function getBigInt($key, $defVal=0, $type='REQUEST') {
		$val = trim(self::get($key,intval($defVal), $type));
		if (ctype_digit($val)) 	return $val;
		$val = preg_replace("/[^0-9](.*)$/", '', $val);
		if (ctype_digit($val)) return $val;
		return 0;
	}
	public static function getInt($key, $defVal=0, $type='REQUEST') {
		return intval(self::get($key,intval($defVal), $type));
	}
	public static function getFloat($key, $defVal=0, $type='REQUEST') {
		return floatval(str_replace(',', '.',self::get($key, $defVal, $type)));
	}
	public static function getBool($key, $defVal=false, $type='REQUEST') {
		return (bool)self::get($key, $defVal, $type);
	}
	public static function getDateTime($key, $defVal=false, $type='REQUEST') {
		$result = self::getSafe($key,"", $type);
		if ($result) return QLPText::toSQL($result,".");
		else return $defVal;
	}
	public static function getDate($key, $defVal=false, $type='REQUEST') {
		$result = self::getSafe($key,"", $type);
		if ($result) return QLPText::toSQL($result,".",true);
		else return $defVal;
	}
	public static function getSafe($key, $defVal='', $type='REQUEST') {
		$result=self::get($key, $defVal, $type);
		if (is_array($result)){
			if (count($result)){
				foreach($result as $key=>$val)	{
					$result[$key]=htmlspecialchars($val,ENT_QUOTES,'UTF-8');
				}
			}
			return $result;
		} else return htmlspecialchars($result,ENT_QUOTES,'UTF-8');
	}
	public static function getHTML($key, $defVal='', $type='REQUEST') {
		return addslashes(self::get($key, $defVal, $type));
	}
	public static function getHost($trimWWW=false) {
		if($trimWWW) return str_replace("www.","",$_SERVER["HTTP_HOST"]);
		else return $_SERVER["HTTP_HOST"];
	}
	public static function getCurrentProtocol() {
		$scheme	=	isset($_SERVER['HTTP_SCHEME'])
					? $_SERVER['HTTP_SCHEME']
					: (
						(isset($_SERVER['HTTPS']) && $_SERVER['HTTPS'] != 'off') || (isset($_SERVER['HTTP_X_FORWARDED_PROTO']) && $_SERVER['HTTP_X_FORWARDED_PROTO'] == 'https') || 443 == $_SERVER['SERVER_PORT']
						? 'https'
						: 'http'
					);
		return $scheme;
	}
}
?>