<?php
// Quick-LP
// Copyright (c) Radius17
// Web: https://quick-lp.ru
// Commercial license https://quick-lp.ru/license.txt
// THE SOFTWARE IS PROVIDED 'AS IS', WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
// Revision: 5c16bf3 (2021-06-01 05:15:46)
//

defined('_QUICK_LP') or die("Access denied");

final class QLPText {
	private static $_defs 			= array();
	private static $_parsedIni		= array();

	public static function _($key) {
		if (isset(self::$_defs[$key])) return self::$_defs[$key];
		$ukey=strtoupper($key);
		if (isset(self::$_defs[$ukey])) return self::$_defs[$ukey];
		if(QLPConfig::$debugMode) QLPDebugger::getInstance()->translation($key);
		return $key;
	}
	public static function parseLanguage($_language="") {
		$iniPath = QLP_ENGINE.'lang'.DS.($_language ? $_language : QLPConfig::$defaultLang).'.ini';
		self::parseIni($iniPath);
	}
	private static function parseIni($iniPath) {
		if (isset(self::$_parsedIni[$iniPath]) && self::$_parsedIni[$iniPath] == $iniPath) {
			// Nothing to do
		} else {
			if (is_file($iniPath)) {
				$newDefs = parse_ini_file($iniPath,false);
				foreach ($newDefs as $key=>$value) self::$_defs[$key] = $value;
				self::$_parsedIni[$iniPath] = $iniPath;
				if(QLPConfig::$debugMode) QLPDebugger::getInstance()->milestone("Loaded language : ".$iniPath);
			}
		}
	}
	public static function toHtml($text){
		return str_replace("\n", "<br />", $text);
	}
	public static function fromHtml($text, $cutLength=0, $cutTextSuffix){
		$pattern = array("/(<p\s*>\s*)/","/(<\/p>)/","/(<br\s*\/?>\s*)/");
		$replace = array("","\n","\n");
		$text = strip_tags(preg_replace($pattern, $replace, $text));
		if ($cutLength) $text = mb_substr($text, 0, $cutLength, DEF_CP).$cutTextSuffix;
		return $text;
	}
	public static function toSQL($sqlDate="", $delimiter=".", $notime=false, $noseconds=false) {
		if (!$sqlDate) {
			$result="0000-00-00 00:00:00";
		} else {
			if($notime) {
				preg_match("/([0-9]{1,2})".$delimiter."([0-9]{1,2})".$delimiter."([0-9]{4})/", $sqlDate, $datetime);
			} else {
				if($noseconds) { preg_match ("/([0-9]{1,2})".$delimiter."([0-9]{1,2})".$delimiter."([0-9]{4}) ([0-9]{1,2}):([0-9]{1,2})/", $sqlDate, $datetime); $datetime[6]='00';	}
				else { preg_match ("/([0-9]{1,2})".$delimiter."([0-9]{1,2})".$delimiter."([0-9]{4}) ([0-9]{1,2}):([0-9]{1,2}):([0-9]{1,2})/", $sqlDate, $datetime); $datetime[4]=$datetime[5]=$datetime[6]='00';}
			}
			if(!isset($datetime[3])) { $result=$sqlDate; }
			else {
				$result = $datetime[3]."-".$datetime[2]."-".$datetime[1];
				if(!$notime) $result.=" ".$datetime[4].":".$datetime[5].":".$datetime[6];
			}
		}
		return $result;
	}
	public static function jsAddSlashes($str)  {
		$pattern = array( "/\\\\/", "/\n/", "/\r/", "/\"/", "/\'/", "/&/", "/</", "/>/" );
		$replace = array( "\\\\\\\\", "\\n", "\\r", "\\\"", "\\'", "\\x26", "\\x3C", "\\x3E" );
		return preg_replace($pattern, $replace, $str);
	}
	public static function translit($string, $coder='UTF-8') {
		$string=htmlentities(html_entity_decode($string,ENT_QUOTES,DEF_CP),ENT_QUOTES,DEF_CP);
		$_html_entities_arr_source=array_keys(array_flip(get_html_translation_table(HTML_ENTITIES)));
		$_html_entities_arr_dest=array_fill(0,count($_html_entities_arr_source),"_");
		$string = mb_strtolower($string, $coder);
		$string = str_replace($_html_entities_arr_source,$_html_entities_arr_dest,$string);
		$string = str_replace(array(
				'&','?','!','.',',',':',';','*','(',')','{','}','%','#','№','@','$','^','+','/','\\','=','|','"','\'','\"',' ',
				'а','б','в','г','д','е','ё','з','и','й','к','л','м','н','о','п','р','с','т','у','ф','х','ъ','ы','э','ж', 'ц', 'ч', 'ш', 'щ',   'ь','ю','я'
		), array(
				'_','_','_','_','_','_','_','_','_','_','_','_','_','_','_','_','_','_','_','_','_', '_','_','_','_', '_', '_',
				'a','b','v','g','d','e','e','z','i','y','k','l','m','n','o','p','r','s','t','u','f','h','j','i','e','zh','ts','ch','sh','shch','','yu','ya'
		), $string);
		$string = preg_replace("/^a-z0-9_/", "", $string);
		$string = trim($string, '_');
		$string = preg_replace("/_{2,}/", "_", $string);
		return $string;
	}
	public static function compareX($a,$b){
		return md5(base64_encode($a))==$b;
	}
}
?>